Ingres-Utility-Netutil version 0.02
This module provides an API to netutil utility for Ingres RDBMS,
which provides local control of IIGCC servers for Ingres Net
inbound and outbound remote connections, and also manage logins
and connections to remote servers, a.k.a. VNodes.
To use this module, the current user should be the Ingres
installation owner, usually "ingres", to have rights to
use all features.
Environment variables (II_SYSTEM et ali) should be set also.
INSTALLATION
To install this module, run the following commands:
perl Makefile.PL
make
make test
make install
Alternatively, to install with Module::Build, you can use the following commands:
perl Build.PL
./Build
./Build test
./Build install
DEPENDENCIES
Expect::Simple
SUPPORT AND DOCUMENTATION
After installing, you can find documentation for this module with the perldoc command.
perldoc Ingres::Utility::IINetutil
You can also look for information at:
Search CPAN
http://search.cpan.org/dist/Ingres-Utility-Netutil
CPAN Request Tracker:
http://rt.cpan.org/NoAuth/Bugs.html?Dist=Ingres-Utility-Netutil
AnnoCPAN, annotated CPAN documentation:
http://annocpan.org/dist/Ingres-Utility-Netutil
CPAN Ratings:
http://cpanratings.perl.org/d/Ingres-Utility-Netutil
COPYRIGHT AND LICENSE
Copyright (C) 2006 Joner Cyrre Worm
This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.
Ingres is a registered brand of Ingres Corporation.